#!/bin/bash

export VERSION="0.5"

clear
echo
echo "Welcome to the Unreal Tournament (Linux 413A) Installer"
echo "Version $VERSION"
echo "written by abfackeln <abfackeln@abfackeln.com>"
echo

if [ ! -f patches/ut-linux-400a.tar.gz ]; then
	echo "patch file ut-linux-400a.tar.gz not found in the patches directory!"
	echo "unable to continue. (make sure file is all lowercase)"
	echo "file can be downloaded from http://unreal.epicgames.com/TournamentVersions.htm"
	exit 0
fi

if [ ! -f patches/ut-patch413a-linux.tar.gz ]; then
	echo "patch file ut-patch413a-linux.tar.gz not found in the patches directory!"
	echo "unable to continue. (make sure file is all lowercase)"
	echo "file can be downloaded from http://unreal.epicgames.com/TournamentVersions.htm"
	exit 0
fi

if [ ! -f patches/netgamesusa.com-1.5.6.tar.gz ]; then
	echo "patch file netgamesusa.com-1.5.6.tar.gz not found in the patches directory!"
	echo "unable to continue."
	exit 0
fi

if [ ! -d /mnt/cdrom/System ]; then
	echo "the unreal cdrom must be mounted at /mnt/cdrom"
	echo "unable to continue."
	exit 0
fi

echo
echo "Please take time now to answer eight quick questions to configure your server"
echo

### get the install directory and the destination directory

INSTALL_DIR=`pwd`

echo "The directory which you install should be the FULL pathname"
echo "and should not already exist, ie. /usr/local/unreal"
echo
echo -n "Enter the directory where you wish to install Unreal Tournament: "
read MYDIR
if [ ! -d "$MYDIR" ]; then
	mkdir "$MYDIR"
else
	echo "Directory already exists."
	echo "can not continue because this will destroy the directory you specified."
	echo "if you really want to use this directory name, delete the existing one first"
	exit 0
fi

if [ ! -d "$MYDIR" ]; then
	echo "Unable to create directory."
	exit 0
fi
cd "$MYDIR"

### create a file /tmp/ut.ini to work on UnrealTournament.ini settings

cp -pf /mnt/cdrom/System/UnrealTournament.ini /tmp/ut.ini

### replace lines in the UnrealTournament.ini file

sed -f $INSTALL_DIR/custom/common.sed /tmp/ut.ini > /tmp/ut2.ini
cp -pf /tmp/ut2.ini /tmp/ut.ini

### add custom .ini settings from the more-ini.txt file

cat $INSTALL_DIR/custom/more-ini.txt >> /tmp/ut.ini

### ask some questions

echo
echo "if you intend to run this program as a user other than root, then enter"
echo "the username here .. if you run as root then it will suid to this user"
echo
echo -n "Enter the userid that the ucc program should run as [nobody]: "
read USERID
if [ "$USERID" = "root" ]; then
	echo "invalid user id; should not run as root"
	rmdir $MYDIR
	exit 0
fi
if [ "$USERID" = "" ]; then
	export USERID="nobody"
fi
export XXTMP=`grep ^$USERID: /etc/passwd`
if [ "$XXTMP" = "" ]; then
	echo "invalid user id"
	rmdir $MYDIR
	exit 0
fi
export XXTMP=""

echo
echo -n "Would you like to install the UT client: "
read INST_CLIENT
if [ "$INST_CLIENT" = "Y" ]; then
	export INST_CLIENT="y"
fi
if [ "$INST_CLIENT" = "YES" ]; then
	export INST_CLIENT="y"
fi
if [ "$INST_CLIENT" = "YEs" ]; then
	export INST_CLIENT="y"
fi
if [ "$INST_CLIENT" = "Yes" ]; then
	export INST_CLIENT="y"
fi
if [ "$INST_CLIENT" = "yes" ]; then
	export INST_CLIENT="y"
fi

echo
echo -n "Enter a name for your server: "
read VAL
sed "s|^ServerName=.*|ServerName=$VAL|" /tmp/ut.ini > /tmp/ut2.ini
cp -pf /tmp/ut2.ini /tmp/ut.ini

echo
echo -n "Enter a username for the Web admin tool: "
read VAL
sed "s|^AdminUsername=.*|AdminUsername=$VAL|" /tmp/ut.ini > /tmp/ut2.ini
cp -pf /tmp/ut2.ini /tmp/ut.ini

echo
echo -n "Enter a password for the web admin tool and the console adminlogin: "
read VAL
sed "s|^AdminPassword=.*|AdminPassword=$VAL|" /tmp/ut.ini > /tmp/ut2.ini
cp -pf /tmp/ut2.ini /tmp/ut.ini

echo
echo -n "Enter the name of the server administrator (Optional): "
read VAL
sed "s|^AdminName=.*|AdminName=$VAL|" /tmp/ut.ini > /tmp/ut2.ini
cp /tmp/ut2.ini /tmp/ut.ini

echo
echo -n "Enter an administrator email address (Optional): "
read VAL
sed "s|^AdminEmail=.*|AdminEmail=$VAL|" /tmp/ut.ini > /tmp/ut2.ini
cp /tmp/ut2.ini /tmp/ut.ini

export LINE1="Installed with abfackeln's Linux UT installer"
export LINE2="http://abfackeln.com/info/ut-installer.html"
export LINE3="To modify this text, go to this url:"
export LINE4="http://$HOSTNAME:8888/"

sed "s|^MOTDLine1=.*|MOTDLine1=$LINE1|" /tmp/ut.ini > /tmp/ut2.ini
sed "s|^MOTDLine2=.*|MOTDLine2=$LINE2|" /tmp/ut2.ini > /tmp/ut.ini
sed "s|^MOTDLine3=.*|MOTDLine3=$LINE3|" /tmp/ut.ini > /tmp/ut2.ini
sed "s|^MOTDLine4=.*|MOTDLine4=$LINE4|" /tmp/ut2.ini > /tmp/ut.ini

echo
echo
echo "Thank you!"
echo "Now, go have a coffee ......"
echo



## now work on installing stuff ..



echo "copying files from the cd -- this will take a while ..."

# copy dos version to our new directory
#cp -pR /mnt/cdrom/Help .
cp -pR /mnt/cdrom/Logs .
cp -pR /mnt/cdrom/Maps .
cp -pR /mnt/cdrom/Music .
#cp -pR /mnt/cdrom/NetGamesUSA.com .
cp -pR /mnt/cdrom/Sounds .
cp -pR /mnt/cdrom/System .
cp -pR /mnt/cdrom/Textures .
cp -pR /mnt/cdrom/Web .

# remove dos-specific files
find . -name "*.dll" -exec rm {} \; 
find . -name "*.exe" -exec rm {} \; 
find . -name "*.EXE" -exec rm {} \; 
find . -name "*.frt" -exec rm {} \; 
find . -name "*.itt" -exec rm {} \; 
find . -name "*.est" -exec rm {} \; 

# install the 400A patch -- this currently only installs the server files

echo
echo "Installing patch from ut-linux-400a.tar.gz ..."

tar zxpf $INSTALL_DIR/patches/ut-linux-400a.tar.gz
# extract linux system patch
tar zxpf UT-Linux-400A/LinuxCoreSystem.tar.gz
if [ "$INST_CLIENT" = "y" ]; then
	# extract client patches
	tar zxpf UT-Linux-400A/LinuxGlideSystem.tar.gz
	tar zxpf UT-Linux-400A/LinuxLogos.tar.gz
	tar zxpf UT-Linux-400A/NetGamesUSA.com_v1_1.tar.gz
	# run setup shell script
	cd UT-Linux-400A
	./setup.sh
	cd ..
fi
# remove patch files
rm -rf UT-Linux-400A

# install bonus pack if the file exists

echo
echo "Looking for bonus packs ..."

if [ -f $INSTALL_DIR/patches/ut-bonuspack.tar.gz ]; then
	echo
	echo "Installing Bonus Pack from ut-bonuspack.tar.gz ..."
	tar zxpf $INSTALL_DIR/patches/ut-bonuspack.tar.gz
fi

if [ -d UT-BonusPack-0.1-beta ]; then
	cp -pf UT-BonusPack-0.1-beta/System/* System
	cp -pf UT-BonusPack-0.1-beta/Textures/* Textures
	cp -pf UT-BonusPack-0.1-beta/Maps/* Maps
	cp -pf UT-BonusPack-0.1-beta/Help/* Help

	echo
	echo "fixing .ini settings that umod should have set but did not."
	sed -f $INSTALL_DIR/custom/bonuspack.sed < /tmp/ut.ini > /tmp/ut2.ini
	mv -f /tmp/ut2.ini /tmp/ut.ini

	echo "removing bonuspack directory";
	rm -rf UT-BonusPack-0.1-beta
else

# proper bonus pack installation -- the above one works, but requires a special tar file
# this next one uses the standard epic umod in a zip file

	if [ -f $INSTALL_DIR/patches/utbonuspack.zip ]; then
		echo
		echo "Installing Bonus Pack from utbonuspack.zip ..."
		unzip -o $INSTALL_DIR/patches/utbonuspack.zip
		cd $INSTALL_DIR/custom/umodpack-abf
		./umod -b $MYDIR -f -i $MYDIR/UTBonusPack.umod
		cd $MYDIR
		rm -f UTBonusPack.umod

		echo
		echo "Fixing Bonus Pack case-insensitivity bug."
		#mv -fv system/* System
		#mv -fv textures/* Textures
		#rmdir system textures
		cd System
		mv -fv relics.int Relics.int
		mv -fv relics.u Relics.u
		mv -fv relicsbindings.int RelicsBindings.int
		mv -fv relicsbindings.u RelicsBindings.u
		mv -fv multimesh.int MultiMesh.int
		mv -fv multimesh.u MultiMesh.u
		mv -fv epiccustommodels.u EpicCustomModels.u
		mv -fv tnalimeshskins.int TNaliMeshSkins.int
		mv -fv tskmskins.int TSkMSkins.int
		mv -fv tcowmeshskins.int TCowMeshSkins.int
		cd ../Textures
		mv -fv tnalimeshskins.utx TNaliMeshSkins.utx
		mv -fv tskmskins.utx TSkMSkins.utx
		mv -fv tcowmeshskins.utx TCowMeshSkins.utx
		cd ..

		echo
		echo "fixing .ini settings that umod should have set but did not."
		sed -f $INSTALL_DIR/custom/bonuspack.sed < /tmp/ut.ini > /tmp/ut2.ini
		mv -f /tmp/ut2.ini /tmp/ut.ini
	fi
fi

# install the inoxx bonus pack if the file exists.

if [ -f $INSTALL_DIR/patches/utinoxxpack.zip ]; then
	echo
	echo "Installing Inoxx Bonus Pack from utinoxxpack.zip ..."
	unzip -o $INSTALL_DIR/patches/utinoxxpack.zip
	cd $INSTALL_DIR/custom/umodpack-abf
	./umod -b $MYDIR -f -i $MYDIR/UTInoxxPack.umod
	cd $MYDIR
	rm -f UTInoxxPack.umod
fi

# install the 413A patch

echo
echo "Installing patch from ut-patch413a-linux.tar.gz ..."

tar zxpf $INSTALL_DIR/patches/ut-patch413a-linux.tar.gz
cd Patch
./install_patch
cd ..
rm -rf Patch

# install NetGamesUSA 1.5.6 and destroy the one packaged in 413A

echo
echo "Fixing NetGames WorldStats .. installing version 1.5.6 ..."

rm -rf NetGamesUSA.com
rm -f NetGamesUSA.com.tar

tar zxpf $INSTALL_DIR/patches/netgamesusa.com-1.5.6.tar.gz

# customize the UnrealTournament.ini file and create init script
# make a copy for each game type

echo
echo "Modifying UnrealTournament.ini file ..."

# DM

MYID="7777"
MYWEB="7776"
MYGAME="DeathMatchPlus"
MYMAP="DM-Barricade"
ABBR="DM"

cp -f $INSTALL_DIR/custom/ucc.init /tmp/ucc.init
sed "s|^ABBR=.*|ABBR=$ABBR|" /tmp/ucc.init > /tmp/ucc2.init
sed "s|^MYDIR=.*|MYDIR=$MYDIR|" /tmp/ucc2.init > /tmp/ucc.init
sed "s|^MYGAME=.*|MYGAME=$MYGAME|" /tmp/ucc.init > /tmp/ucc2.init
sed "s|^MYMAP=.*|MYMAP=$MYMAP|" /tmp/ucc2.init > /tmp/ucc.init
sed "s|^MYUSERID=.*|MYUSERID=$USERID|" /tmp/ucc.init > ./ucc-$ABBR.init
rm -f /tmp/ucc.init /tmp/ucc2.init
chmod u+x ucc-$ABBR.init
export VAL2=$[$MYID+3]
sed "s|^MOTDLine4=.*|MOTDLine4=http://$HOSTNAME:$MYWEB/|" /tmp/ut.ini > /tmp/ut2.ini
sed "s|^ListenPort=.*|ListenPort=$MYWEB|" /tmp/ut2.ini > /tmp/ut3.ini
sed "s|^DefaultServerGame=.*|DefaultServerGame=Botpack.$MYGAME|" /tmp/ut3.ini > /tmp/ut2.ini
sed "s|^Port=.*|Port=$MYID|" /tmp/ut2.ini > /tmp/ut-$ABBR.ini

# CTF

MYID="7767"
MYWEB="7766"
MYGAME="CTFGame"
MYMAP="CTF-Coret"
ABBR="CTF"

cp -f $INSTALL_DIR/custom/ucc.init /tmp/ucc.init
sed "s|^ABBR=.*|ABBR=$ABBR|" /tmp/ucc.init > /tmp/ucc2.init
sed "s|^MYDIR=.*|MYDIR=$MYDIR|" /tmp/ucc2.init > /tmp/ucc.init
sed "s|^MYGAME=.*|MYGAME=$MYGAME|" /tmp/ucc.init > /tmp/ucc2.init
sed "s|^MYMAP=.*|MYMAP=$MYMAP|" /tmp/ucc2.init > /tmp/ucc.init
sed "s|^MYUSERID=.*|MYUSERID=$USERID|" /tmp/ucc.init > ./ucc-$ABBR.init
rm -f /tmp/ucc.init /tmp/ucc2.init
chmod u+x ucc-$ABBR.init
export VAL2=$[$MYID+3]
sed "s|^MOTDLine4=.*|MOTDLine4=http://$HOSTNAME:$MYWEB/|" /tmp/ut.ini > /tmp/ut2.ini
sed "s|^ListenPort=.*|ListenPort=$MYWEB|" /tmp/ut2.ini > /tmp/ut3.ini
sed "s|^DefaultServerGame=.*|DefaultServerGame=Botpack.$MYGAME|" /tmp/ut3.ini > /tmp/ut2.ini
sed "s|^Port=.*|Port=$MYID|" /tmp/ut2.ini > /tmp/ut-$ABBR.ini

# DOM

MYID="7757"
MYWEB="7756"
MYGAME="Domination"
MYMAP="DOM-Cinder"
ABBR="DOM"

cp -f $INSTALL_DIR/custom/ucc.init /tmp/ucc.init
sed "s|^ABBR=.*|ABBR=$ABBR|" /tmp/ucc.init > /tmp/ucc2.init
sed "s|^MYDIR=.*|MYDIR=$MYDIR|" /tmp/ucc2.init > /tmp/ucc.init
sed "s|^MYGAME=.*|MYGAME=$MYGAME|" /tmp/ucc.init > /tmp/ucc2.init
sed "s|^MYMAP=.*|MYMAP=$MYMAP|" /tmp/ucc2.init > /tmp/ucc.init
sed "s|^MYUSERID=.*|MYUSERID=$USERID|" /tmp/ucc.init > ./ucc-$ABBR.init
rm -f /tmp/ucc.init /tmp/ucc2.init
chmod u+x ucc-$ABBR.init
export VAL2=$[$MYID+3]
sed "s|^MOTDLine4=.*|MOTDLine4=http://$HOSTNAME:$MYWEB/|" /tmp/ut.ini > /tmp/ut2.ini
sed "s|^ListenPort=.*|ListenPort=$MYWEB|" /tmp/ut2.ini > /tmp/ut3.ini
sed "s|^DefaultServerGame=.*|DefaultServerGame=Botpack.$MYGAME|" /tmp/ut3.ini > /tmp/ut2.ini
sed "s|^Port=.*|Port=$MYID|" /tmp/ut2.ini > /tmp/ut-$ABBR.ini

# AS

MYID="7747"
MYWEB="7746"
MYGAME="Assault"
MYMAP="AS-Frigate"
ABBR="AS"

cp -f $INSTALL_DIR/custom/ucc.init /tmp/ucc.init
sed "s|^ABBR=.*|ABBR=$ABBR|" /tmp/ucc.init > /tmp/ucc2.init
sed "s|^MYDIR=.*|MYDIR=$MYDIR|" /tmp/ucc2.init > /tmp/ucc.init
sed "s|^MYGAME=.*|MYGAME=$MYGAME|" /tmp/ucc.init > /tmp/ucc2.init
sed "s|^MYMAP=.*|MYMAP=$MYMAP|" /tmp/ucc2.init > /tmp/ucc.init
sed "s|^MYUSERID=.*|MYUSERID=$USERID|" /tmp/ucc.init > ./ucc-$ABBR.init
rm -f /tmp/ucc.init /tmp/ucc2.init
chmod u+x ucc-$ABBR.init
export VAL2=$[$MYID+3]
sed "s|^MOTDLine4=.*|MOTDLine4=http://$HOSTNAME:$MYWEB/|" /tmp/ut.ini > /tmp/ut2.ini
sed "s|^ListenPort=.*|ListenPort=$MYWEB|" /tmp/ut2.ini > /tmp/ut3.ini
sed "s|^DefaultServerGame=.*|DefaultServerGame=Botpack.$MYGAME|" /tmp/ut3.ini > /tmp/ut2.ini
sed "s|^Port=.*|Port=$MYID|" /tmp/ut2.ini > /tmp/ut-$ABBR.ini

rm -f /tmp/ut3.ini /tmp/ut2.ini /tmp/ut.ini

# copy the ini file and a backup and set up different game links

cd System
cp -pvf /mnt/cdrom/System/UnrealTournament.ini UnrealTournament.ini.orig
mv -vf /tmp/ut-DM.ini UnrealTournament-DM.ini
mv -vf /tmp/ut-CTF.ini UnrealTournament-CTF.ini
mv -vf /tmp/ut-AS.ini UnrealTournament-AS.ini
mv -vf /tmp/ut-DOM.ini UnrealTournament-DOM.ini
ln -sf UnrealTournament-DM.ini UnrealTournament.ini
ln -sf ucc ucc-DM
ln -sf ucc ucc-CTF
ln -sf ucc ucc-AS
ln -sf ucc ucc-DOM
cd ..

### set bots to autoadjust skill .. this is generally best for everyone

sed 's/^bAdjustSkill=[A-Za-z]*/bAdjustSkill=True/' System/User.ini > /tmp/User.ini
mv -f /tmp/User.ini System/User.ini


# make the nobody user have full access to everything

chown -R $USERID .

# generic bots

cp -p System/User.ini System/User.ini.old-bots
$INSTALL_DIR/custom/generic-bots.sh System/User.ini.old-bots > System/User.ini

# all done

echo
echo "Installation Complete"
echo
echo "to start the server enter the command:"
echo "$MYDIR/ucc-DM.init start"
echo

# EOF
